# Ino-on, Inc. LoRa Device Packet Specification code.
This code includes frame specification and python parser.

For runing all test run:
    $ ./test.sh
or
    $ python -m unittest discover -v

For running specific test run:
    $ python -m unittest tests.<test moule name or function> -v
